@@ -8,14 +8,13 @@ use anchor_spl::{
 };
 
 #[derive(Accounts)]
-#[instruction(bump: u8)]
 pub struct CreateMintManagerCtx<'info> {
     #[account(
         init,
         payer = payer,
         space = MINT_MANAGER_SIZE,
         seeds = [MINT_MANAGER_SEED.as_bytes(), mint.key().as_ref()],
-        bump = bump,
+        bump,
     )]
     pub mint_manager: Account<'info, MintManager>, 
     #[account(mut, constraint = mint.freeze_authority.unwrap() == freeze_authority.key() @ ErrorCode::InvalidFreezeAuthority)]
@@ -27,12 +26,12 @@ pub struct CreateMintManagerCtx<'info> {
     pub system_program: Program<'info, System>,
 }
 
-pub fn handler(ctx: Context<CreateMintManagerCtx>, bump: u8) -> ProgramResult {
+pub fn handler(ctx: Context<CreateMintManagerCtx>) -> ProgramResult {
     // set mint manager data
     let mint_manager = &mut ctx.accounts.mint_manager;
     mint_manager.initializer = ctx.accounts.freeze_authority.key();
     mint_manager.token_managers = 0;
-    mint_manager.bump = bump;
+    mint_manager.bump = *ctx.bumps.get("mint_manager").unwrap();
 
     // set freeze authority of mint to mint manager
     let cpi_accounts = SetAuthority {
