@@ -4,7 +4,7 @@ use {
 };
 
 #[derive(Accounts)]
-#[instruction(bump: u8, target: Pubkey)]
+#[instruction(target: Pubkey)]
 pub struct CreateTransferReceiptCtx<'info> {
     #[account(mut)]
     token_manager: Box<Account<'info, TokenManager>>,
@@ -19,13 +19,13 @@ pub struct CreateTransferReceiptCtx<'info> {
     #[account(
         init,
         payer = transfer_authority,
-        seeds = [TRANSFER_RECEIPT_SEED.as_bytes(), token_manager.key().as_ref(), target.key().as_ref()], bump = bump,
+        seeds = [TRANSFER_RECEIPT_SEED.as_bytes(), token_manager.key().as_ref(), target.as_ref()], bump,
         space = TRANSFER_RECEIPT_SIZE,
     )]
     transfer_receipt: Box<Account<'info, TranferReceipt>>,
     system_program: Program<'info, System>,
 }
 
-pub fn handler(_ctx: Context<CreateTransferReceiptCtx>, _bump: u8, _target: Pubkey) -> ProgramResult {
+pub fn handler(_ctx: Context<CreateTransferReceiptCtx>, _target: Pubkey) -> ProgramResult {
     return Ok(())
 }
\ No newline at end of file
